pub enum LoadError {
Library(Error),
MissingEntryPoint,
}Expand description
Error returned when the Vulkan shared library cannot be loaded.
This is distinct from vk::Result, it represents a failure to reach
the Vulkan API at all, not a Vulkan API error.
Examples
use vulkan_rust::LoadError;
let err = LoadError::MissingEntryPoint;
assert_eq!(
err.to_string(),
"vkGetInstanceProcAddr not found in Vulkan library",
);Variants
Library(Error)
The Vulkan shared library could not be found or opened.
MissingEntryPoint
vkGetInstanceProcAddr could not be resolved from the library.