Version

Struct Version 

pub struct Version {
    pub major: u32,
    pub minor: u32,
    pub patch: u32,
}
Decoded Vulkan API version (major.minor.patch).

Vulkan packs versions into a u32: major (bits 31-22), minor (21-12), patch (11-0). This type provides named fields and a Display impl.

Examples

use vulkan_rust::Version;

let v = Version::from_raw(0x00403000);
assert_eq!(v.to_string(), "1.3.0");
assert_eq!(v.to_raw(), 0x00403000);

Fields

major: u32

Major version number (bits 31-22 of the packed u32).

minor: u32

Minor version number (bits 21-12 of the packed u32).

patch: u32

Patch version number (bits 11-0 of the packed u32).

Implementations

Source

impl Version

pub const fn new(major: u32, minor: u32, patch: u32) -> Self

Create a version from major, minor, and patch components.

use vulkan_rust::Version;

let v = Version::new(1, 3, 0);
assert_eq!(v.to_raw(), 0x00403000);
assert_eq!(v.to_string(), "1.3.0");
pub const fn from_raw(raw: u32) -> Self

Decode a packed Vulkan version u32 into its components.

use vulkan_rust::Version;

let v = Version::from_raw(0x00403000); // Vulkan 1.3.0
assert_eq!(v.major, 1);
assert_eq!(v.minor, 3);
assert_eq!(v.patch, 0);
pub const fn to_raw(self) -> u32

Encode this version back into the packed u32 representation.

use vulkan_rust::Version;

let v = Version { major: 1, minor: 3, patch: 0 };
assert_eq!(v.to_raw(), 0x00403000);