EntryCommands

Struct EntryCommands 

pub struct EntryCommands {
    pub create_instance: Option<unsafe extern "system" fn(*const InstanceCreateInfo, *const AllocationCallbacks, *mut Instance) -> Result>,
    pub enumerate_instance_version: Option<unsafe extern "system" fn(*mut u32) -> Result>,
    pub enumerate_instance_layer_properties: Option<unsafe extern "system" fn(*mut u32, *mut LayerProperties) -> Result>,
    pub enumerate_instance_extension_properties: Option<unsafe extern "system" fn(*const i8, *mut u32, *mut ExtensionProperties) -> Result>,
    pub get_external_compute_queue_data_nv: Option<unsafe extern "system" fn(ExternalComputeQueueNV, *mut ExternalComputeQueueDataParamsNV, *mut c_void)>,
}

Fields

create_instance: Option<unsafe extern "system" fn(*const InstanceCreateInfo, *const AllocationCallbacks, *mut Instance) -> Result>enumerate_instance_version: Option<unsafe extern "system" fn(*mut u32) -> Result>enumerate_instance_layer_properties: Option<unsafe extern "system" fn(*mut u32, *mut LayerProperties) -> Result>enumerate_instance_extension_properties: Option<unsafe extern "system" fn(*const i8, *mut u32, *mut ExtensionProperties) -> Result>get_external_compute_queue_data_nv: Option<unsafe extern "system" fn(ExternalComputeQueueNV, *mut ExternalComputeQueueDataParamsNV, *mut c_void)>

Implementations

Source

impl EntryCommands

pub unsafe fn load(f: impl FnMut(&CStr) -> *const c_void) -> EntryCommands

Load all function pointers from the given loader callback.

Load all function pointers from the given loader callback.

Safety

The loader must return valid function pointers compatible with each command’s signature, or null for unavailable commands.