pub struct InstanceCommands {Show 107 fields
pub destroy_instance: Option<unsafe extern "system" fn(Instance, *const AllocationCallbacks)>,
pub enumerate_physical_devices: Option<unsafe extern "system" fn(Instance, *mut u32, *mut PhysicalDevice) -> Result>,
pub get_instance_proc_addr: Option<unsafe extern "system" fn(Instance, *const i8) -> Option<unsafe extern "system" fn()>>,
pub get_physical_device_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceProperties)>,
pub get_physical_device_queue_family_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut QueueFamilyProperties)>,
pub get_physical_device_memory_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceMemoryProperties)>,
pub get_physical_device_features: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceFeatures)>,
pub get_physical_device_format_properties: Option<unsafe extern "system" fn(PhysicalDevice, Format, *mut FormatProperties)>,
pub get_physical_device_image_format_properties: Option<unsafe extern "system" fn(PhysicalDevice, Format, ImageType, ImageTiling, ImageUsageFlagBits, ImageCreateFlagBits, *mut ImageFormatProperties) -> Result>,
pub create_device: Option<unsafe extern "system" fn(PhysicalDevice, *const DeviceCreateInfo, *const AllocationCallbacks, *mut Device) -> Result>,
pub enumerate_device_layer_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut LayerProperties) -> Result>,
pub enumerate_device_extension_properties: Option<unsafe extern "system" fn(PhysicalDevice, *const i8, *mut u32, *mut ExtensionProperties) -> Result>,
pub get_physical_device_sparse_image_format_properties: Option<unsafe extern "system" fn(PhysicalDevice, Format, ImageType, SampleCountFlagBits, ImageUsageFlagBits, ImageTiling, *mut u32, *mut SparseImageFormatProperties)>,
pub create_android_surface_khr: Option<unsafe extern "system" fn(Instance, *const AndroidSurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub create_surface_ohos: Option<unsafe extern "system" fn(Instance, *const SurfaceCreateInfoOHOS, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_display_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut DisplayPropertiesKHR) -> Result>,
pub get_physical_device_display_plane_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut DisplayPlanePropertiesKHR) -> Result>,
pub get_display_plane_supported_displays_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut u32, *mut DisplayKHR) -> Result>,
pub get_display_mode_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR, *mut u32, *mut DisplayModePropertiesKHR) -> Result>,
pub create_display_mode_khr: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR, *const DisplayModeCreateInfoKHR, *const AllocationCallbacks, *mut DisplayModeKHR) -> Result>,
pub get_display_plane_capabilities_khr: Option<unsafe extern "system" fn(PhysicalDevice, DisplayModeKHR, u32, *mut DisplayPlaneCapabilitiesKHR) -> Result>,
pub create_display_plane_surface_khr: Option<unsafe extern "system" fn(Instance, *const DisplaySurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub destroy_surface_khr: Option<unsafe extern "system" fn(Instance, SurfaceKHR, *const AllocationCallbacks)>,
pub get_physical_device_surface_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, SurfaceKHR, *mut u32) -> Result>,
pub get_physical_device_surface_capabilities_khr: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut SurfaceCapabilitiesKHR) -> Result>,
pub get_physical_device_surface_formats_khr: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut u32, *mut SurfaceFormatKHR) -> Result>,
pub get_physical_device_surface_present_modes_khr: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut u32, *mut PresentModeKHR) -> Result>,
pub create_vi_surface_nn: Option<unsafe extern "system" fn(Instance, *const ViSurfaceCreateInfoNN, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub create_wayland_surface_khr: Option<unsafe extern "system" fn(Instance, *const WaylandSurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_wayland_presentation_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void) -> u32>,
pub create_ubm_surface_sec: Option<unsafe extern "system" fn(Instance, *const UbmSurfaceCreateInfoSEC, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_ubm_presentation_support_sec: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void) -> u32>,
pub create_win32_surface_khr: Option<unsafe extern "system" fn(Instance, *const Win32SurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_win32_presentation_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32) -> u32>,
pub create_xlib_surface_khr: Option<unsafe extern "system" fn(Instance, *const XlibSurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_xlib_presentation_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void, u64) -> u32>,
pub create_xcb_surface_khr: Option<unsafe extern "system" fn(Instance, *const XcbSurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_xcb_presentation_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void, u32) -> u32>,
pub create_direct_fb_surface_ext: Option<unsafe extern "system" fn(Instance, *const DirectFBSurfaceCreateInfoEXT, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_direct_fb_presentation_support_ext: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void) -> u32>,
pub create_image_pipe_surface_fuchsia: Option<unsafe extern "system" fn(Instance, *const ImagePipeSurfaceCreateInfoFUCHSIA, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub create_stream_descriptor_surface_ggp: Option<unsafe extern "system" fn(Instance, *const StreamDescriptorSurfaceCreateInfoGGP, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub create_screen_surface_qnx: Option<unsafe extern "system" fn(Instance, *const ScreenSurfaceCreateInfoQNX, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_screen_presentation_support_qnx: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void) -> u32>,
pub create_debug_report_callback_ext: Option<unsafe extern "system" fn(Instance, *const DebugReportCallbackCreateInfoEXT, *const AllocationCallbacks, *mut DebugReportCallbackEXT) -> Result>,
pub destroy_debug_report_callback_ext: Option<unsafe extern "system" fn(Instance, DebugReportCallbackEXT, *const AllocationCallbacks)>,
pub debug_report_message_ext: Option<unsafe extern "system" fn(Instance, DebugReportFlagBitsEXT, DebugReportObjectTypeEXT, u64, usize, i32, *const i8, *const i8)>,
pub get_physical_device_external_image_format_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, Format, ImageType, ImageTiling, ImageUsageFlagBits, ImageCreateFlagBits, ExternalMemoryHandleTypeFlagBitsNV, *mut ExternalImageFormatPropertiesNV) -> Result>,
pub get_physical_device_features2: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceFeatures2)>,
pub get_physical_device_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceProperties2)>,
pub get_physical_device_format_properties2: Option<unsafe extern "system" fn(PhysicalDevice, Format, *mut FormatProperties2)>,
pub get_physical_device_image_format_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceImageFormatInfo2, *mut ImageFormatProperties2) -> Result>,
pub get_physical_device_queue_family_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut QueueFamilyProperties2)>,
pub get_physical_device_memory_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceMemoryProperties2)>,
pub get_physical_device_sparse_image_format_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceSparseImageFormatInfo2, *mut u32, *mut SparseImageFormatProperties2)>,
pub get_physical_device_external_buffer_properties: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceExternalBufferInfo, *mut ExternalBufferProperties)>,
pub get_physical_device_external_memory_sci_buf_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, ExternalMemoryHandleTypeFlagBits, *const c_void, *mut MemorySciBufPropertiesNV) -> Result>,
pub get_physical_device_sci_buf_attributes_nv: Option<unsafe extern "system" fn(PhysicalDevice, *const c_void) -> Result>,
pub get_physical_device_external_semaphore_properties: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceExternalSemaphoreInfo, *mut ExternalSemaphoreProperties)>,
pub get_physical_device_external_fence_properties: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceExternalFenceInfo, *mut ExternalFenceProperties)>,
pub get_physical_device_sci_sync_attributes_nv: Option<unsafe extern "system" fn(PhysicalDevice, *const SciSyncAttributesInfoNV, *const c_void) -> Result>,
pub release_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR) -> Result>,
pub acquire_xlib_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, *mut c_void, DisplayKHR) -> Result>,
pub get_rand_r_output_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, *mut c_void, u64, *mut DisplayKHR) -> Result>,
pub acquire_winrt_display_nv: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR) -> Result>,
pub get_winrt_display_nv: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut DisplayKHR) -> Result>,
pub get_physical_device_surface_capabilities2_ext: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut SurfaceCapabilities2EXT) -> Result>,
pub enumerate_physical_device_groups: Option<unsafe extern "system" fn(Instance, *mut u32, *mut PhysicalDeviceGroupProperties) -> Result>,
pub get_physical_device_present_rectangles_khr: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut u32, *mut Rect2D) -> Result>,
pub create_ios_surface_mvk: Option<unsafe extern "system" fn(Instance, *const IOSSurfaceCreateInfoMVK, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub create_mac_os_surface_mvk: Option<unsafe extern "system" fn(Instance, *const MacOSSurfaceCreateInfoMVK, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub create_metal_surface_ext: Option<unsafe extern "system" fn(Instance, *const MetalSurfaceCreateInfoEXT, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_multisample_properties_ext: Option<unsafe extern "system" fn(PhysicalDevice, SampleCountFlagBits, *mut MultisamplePropertiesEXT)>,
pub get_physical_device_surface_capabilities2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceSurfaceInfo2KHR, *mut SurfaceCapabilities2KHR) -> Result>,
pub get_physical_device_surface_formats2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceSurfaceInfo2KHR, *mut u32, *mut SurfaceFormat2KHR) -> Result>,
pub get_physical_device_display_properties2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut DisplayProperties2KHR) -> Result>,
pub get_physical_device_display_plane_properties2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut DisplayPlaneProperties2KHR) -> Result>,
pub get_display_mode_properties2_khr: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR, *mut u32, *mut DisplayModeProperties2KHR) -> Result>,
pub get_display_plane_capabilities2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const DisplayPlaneInfo2KHR, *mut DisplayPlaneCapabilities2KHR) -> Result>,
pub get_physical_device_calibrateable_time_domains_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut TimeDomainKHR) -> Result>,
pub create_debug_utils_messenger_ext: Option<unsafe extern "system" fn(Instance, *const DebugUtilsMessengerCreateInfoEXT, *const AllocationCallbacks, *mut DebugUtilsMessengerEXT) -> Result>,
pub destroy_debug_utils_messenger_ext: Option<unsafe extern "system" fn(Instance, DebugUtilsMessengerEXT, *const AllocationCallbacks)>,
pub submit_debug_utils_message_ext: Option<unsafe extern "system" fn(Instance, DebugUtilsMessageSeverityFlagBitsEXT, DebugUtilsMessageTypeFlagBitsEXT, *const DebugUtilsMessengerCallbackDataEXT)>,
pub get_physical_device_cooperative_matrix_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut CooperativeMatrixPropertiesNV) -> Result>,
pub get_physical_device_surface_present_modes2_ext: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceSurfaceInfo2KHR, *mut u32, *mut PresentModeKHR) -> Result>,
pub enumerate_physical_device_queue_family_performance_query_counters_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut u32, *mut PerformanceCounterKHR, *mut PerformanceCounterDescriptionKHR) -> Result>,
pub get_physical_device_queue_family_performance_query_passes_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const QueryPoolPerformanceCreateInfoKHR, *mut u32)>,
pub create_headless_surface_ext: Option<unsafe extern "system" fn(Instance, *const HeadlessSurfaceCreateInfoEXT, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>,
pub get_physical_device_supported_framebuffer_mixed_samples_combinations_nv: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut FramebufferMixedSamplesCombinationNV) -> Result>,
pub get_physical_device_tool_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut PhysicalDeviceToolProperties) -> Result>,
pub get_physical_device_refreshable_object_types_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut ObjectType) -> Result>,
pub get_physical_device_fragment_shading_rates_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut PhysicalDeviceFragmentShadingRateKHR) -> Result>,
pub get_physical_device_video_capabilities_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const VideoProfileInfoKHR, *mut VideoCapabilitiesKHR) -> Result>,
pub get_physical_device_video_format_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceVideoFormatInfoKHR, *mut u32, *mut VideoFormatPropertiesKHR) -> Result>,
pub get_physical_device_video_encode_quality_level_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceVideoEncodeQualityLevelInfoKHR, *mut VideoEncodeQualityLevelPropertiesKHR) -> Result>,
pub acquire_drm_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, i32, DisplayKHR) -> Result>,
pub get_drm_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, i32, u32, *mut DisplayKHR) -> Result>,
pub get_physical_device_optical_flow_image_formats_nv: Option<unsafe extern "system" fn(PhysicalDevice, *const OpticalFlowImageFormatInfoNV, *mut u32, *mut OpticalFlowImageFormatPropertiesNV) -> Result>,
pub get_physical_device_cooperative_matrix_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut CooperativeMatrixPropertiesKHR) -> Result>,
pub get_physical_device_cooperative_matrix_flexible_dimensions_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut CooperativeMatrixFlexibleDimensionsPropertiesNV) -> Result>,
pub get_physical_device_cooperative_vector_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut CooperativeVectorPropertiesNV) -> Result>,
pub enumerate_physical_device_shader_instrumentation_metrics_arm: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut ShaderInstrumentationMetricDescriptionARM) -> Result>,
pub get_physical_device_external_tensor_properties_arm: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceExternalTensorInfoARM, *mut ExternalTensorPropertiesARM)>,
pub get_physical_device_queue_family_data_graph_properties_arm: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut u32, *mut QueueFamilyDataGraphPropertiesARM) -> Result>,
pub get_physical_device_queue_family_data_graph_processing_engine_properties_arm: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceQueueFamilyDataGraphProcessingEngineInfoARM, *mut QueueFamilyDataGraphProcessingEnginePropertiesARM)>,
pub enumerate_physical_device_queue_family_performance_counters_by_region_arm: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut u32, *mut PerformanceCounterARM, *mut PerformanceCounterDescriptionARM) -> Result>,
pub get_physical_device_descriptor_size_ext: Option<unsafe extern "system" fn(PhysicalDevice, DescriptorType) -> u64>,
}Fields
destroy_instance: Option<unsafe extern "system" fn(Instance, *const AllocationCallbacks)>enumerate_physical_devices: Option<unsafe extern "system" fn(Instance, *mut u32, *mut PhysicalDevice) -> Result>get_instance_proc_addr: Option<unsafe extern "system" fn(Instance, *const i8) -> Option<unsafe extern "system" fn()>>get_physical_device_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceProperties)>get_physical_device_queue_family_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut QueueFamilyProperties)>get_physical_device_memory_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceMemoryProperties)>get_physical_device_features: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceFeatures)>get_physical_device_format_properties: Option<unsafe extern "system" fn(PhysicalDevice, Format, *mut FormatProperties)>get_physical_device_image_format_properties: Option<unsafe extern "system" fn(PhysicalDevice, Format, ImageType, ImageTiling, ImageUsageFlagBits, ImageCreateFlagBits, *mut ImageFormatProperties) -> Result>create_device: Option<unsafe extern "system" fn(PhysicalDevice, *const DeviceCreateInfo, *const AllocationCallbacks, *mut Device) -> Result>enumerate_device_layer_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut LayerProperties) -> Result>enumerate_device_extension_properties: Option<unsafe extern "system" fn(PhysicalDevice, *const i8, *mut u32, *mut ExtensionProperties) -> Result>get_physical_device_sparse_image_format_properties: Option<unsafe extern "system" fn(PhysicalDevice, Format, ImageType, SampleCountFlagBits, ImageUsageFlagBits, ImageTiling, *mut u32, *mut SparseImageFormatProperties)>create_android_surface_khr: Option<unsafe extern "system" fn(Instance, *const AndroidSurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>create_surface_ohos: Option<unsafe extern "system" fn(Instance, *const SurfaceCreateInfoOHOS, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_display_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut DisplayPropertiesKHR) -> Result>get_physical_device_display_plane_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut DisplayPlanePropertiesKHR) -> Result>get_display_plane_supported_displays_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut u32, *mut DisplayKHR) -> Result>get_display_mode_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR, *mut u32, *mut DisplayModePropertiesKHR) -> Result>create_display_mode_khr: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR, *const DisplayModeCreateInfoKHR, *const AllocationCallbacks, *mut DisplayModeKHR) -> Result>get_display_plane_capabilities_khr: Option<unsafe extern "system" fn(PhysicalDevice, DisplayModeKHR, u32, *mut DisplayPlaneCapabilitiesKHR) -> Result>create_display_plane_surface_khr: Option<unsafe extern "system" fn(Instance, *const DisplaySurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>destroy_surface_khr: Option<unsafe extern "system" fn(Instance, SurfaceKHR, *const AllocationCallbacks)>get_physical_device_surface_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, SurfaceKHR, *mut u32) -> Result>get_physical_device_surface_capabilities_khr: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut SurfaceCapabilitiesKHR) -> Result>get_physical_device_surface_formats_khr: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut u32, *mut SurfaceFormatKHR) -> Result>get_physical_device_surface_present_modes_khr: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut u32, *mut PresentModeKHR) -> Result>create_vi_surface_nn: Option<unsafe extern "system" fn(Instance, *const ViSurfaceCreateInfoNN, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>create_wayland_surface_khr: Option<unsafe extern "system" fn(Instance, *const WaylandSurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_wayland_presentation_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void) -> u32>create_ubm_surface_sec: Option<unsafe extern "system" fn(Instance, *const UbmSurfaceCreateInfoSEC, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_ubm_presentation_support_sec: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void) -> u32>create_win32_surface_khr: Option<unsafe extern "system" fn(Instance, *const Win32SurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_win32_presentation_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32) -> u32>create_xlib_surface_khr: Option<unsafe extern "system" fn(Instance, *const XlibSurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_xlib_presentation_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void, u64) -> u32>create_xcb_surface_khr: Option<unsafe extern "system" fn(Instance, *const XcbSurfaceCreateInfoKHR, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_xcb_presentation_support_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void, u32) -> u32>create_direct_fb_surface_ext: Option<unsafe extern "system" fn(Instance, *const DirectFBSurfaceCreateInfoEXT, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_direct_fb_presentation_support_ext: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void) -> u32>create_image_pipe_surface_fuchsia: Option<unsafe extern "system" fn(Instance, *const ImagePipeSurfaceCreateInfoFUCHSIA, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>create_stream_descriptor_surface_ggp: Option<unsafe extern "system" fn(Instance, *const StreamDescriptorSurfaceCreateInfoGGP, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>create_screen_surface_qnx: Option<unsafe extern "system" fn(Instance, *const ScreenSurfaceCreateInfoQNX, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_screen_presentation_support_qnx: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut c_void) -> u32>create_debug_report_callback_ext: Option<unsafe extern "system" fn(Instance, *const DebugReportCallbackCreateInfoEXT, *const AllocationCallbacks, *mut DebugReportCallbackEXT) -> Result>destroy_debug_report_callback_ext: Option<unsafe extern "system" fn(Instance, DebugReportCallbackEXT, *const AllocationCallbacks)>debug_report_message_ext: Option<unsafe extern "system" fn(Instance, DebugReportFlagBitsEXT, DebugReportObjectTypeEXT, u64, usize, i32, *const i8, *const i8)>get_physical_device_external_image_format_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, Format, ImageType, ImageTiling, ImageUsageFlagBits, ImageCreateFlagBits, ExternalMemoryHandleTypeFlagBitsNV, *mut ExternalImageFormatPropertiesNV) -> Result>get_physical_device_features2: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceFeatures2)>get_physical_device_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceProperties2)>get_physical_device_format_properties2: Option<unsafe extern "system" fn(PhysicalDevice, Format, *mut FormatProperties2)>get_physical_device_image_format_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceImageFormatInfo2, *mut ImageFormatProperties2) -> Result>get_physical_device_queue_family_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut QueueFamilyProperties2)>get_physical_device_memory_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *mut PhysicalDeviceMemoryProperties2)>get_physical_device_sparse_image_format_properties2: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceSparseImageFormatInfo2, *mut u32, *mut SparseImageFormatProperties2)>get_physical_device_external_buffer_properties: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceExternalBufferInfo, *mut ExternalBufferProperties)>get_physical_device_external_memory_sci_buf_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, ExternalMemoryHandleTypeFlagBits, *const c_void, *mut MemorySciBufPropertiesNV) -> Result>get_physical_device_sci_buf_attributes_nv: Option<unsafe extern "system" fn(PhysicalDevice, *const c_void) -> Result>get_physical_device_external_semaphore_properties: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceExternalSemaphoreInfo, *mut ExternalSemaphoreProperties)>get_physical_device_external_fence_properties: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceExternalFenceInfo, *mut ExternalFenceProperties)>get_physical_device_sci_sync_attributes_nv: Option<unsafe extern "system" fn(PhysicalDevice, *const SciSyncAttributesInfoNV, *const c_void) -> Result>release_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR) -> Result>acquire_xlib_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, *mut c_void, DisplayKHR) -> Result>get_rand_r_output_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, *mut c_void, u64, *mut DisplayKHR) -> Result>acquire_winrt_display_nv: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR) -> Result>get_winrt_display_nv: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut DisplayKHR) -> Result>get_physical_device_surface_capabilities2_ext: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut SurfaceCapabilities2EXT) -> Result>enumerate_physical_device_groups: Option<unsafe extern "system" fn(Instance, *mut u32, *mut PhysicalDeviceGroupProperties) -> Result>get_physical_device_present_rectangles_khr: Option<unsafe extern "system" fn(PhysicalDevice, SurfaceKHR, *mut u32, *mut Rect2D) -> Result>create_ios_surface_mvk: Option<unsafe extern "system" fn(Instance, *const IOSSurfaceCreateInfoMVK, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>create_mac_os_surface_mvk: Option<unsafe extern "system" fn(Instance, *const MacOSSurfaceCreateInfoMVK, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>create_metal_surface_ext: Option<unsafe extern "system" fn(Instance, *const MetalSurfaceCreateInfoEXT, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_multisample_properties_ext: Option<unsafe extern "system" fn(PhysicalDevice, SampleCountFlagBits, *mut MultisamplePropertiesEXT)>get_physical_device_surface_capabilities2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceSurfaceInfo2KHR, *mut SurfaceCapabilities2KHR) -> Result>get_physical_device_surface_formats2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceSurfaceInfo2KHR, *mut u32, *mut SurfaceFormat2KHR) -> Result>get_physical_device_display_properties2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut DisplayProperties2KHR) -> Result>get_physical_device_display_plane_properties2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut DisplayPlaneProperties2KHR) -> Result>get_display_mode_properties2_khr: Option<unsafe extern "system" fn(PhysicalDevice, DisplayKHR, *mut u32, *mut DisplayModeProperties2KHR) -> Result>get_display_plane_capabilities2_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const DisplayPlaneInfo2KHR, *mut DisplayPlaneCapabilities2KHR) -> Result>get_physical_device_calibrateable_time_domains_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut TimeDomainKHR) -> Result>create_debug_utils_messenger_ext: Option<unsafe extern "system" fn(Instance, *const DebugUtilsMessengerCreateInfoEXT, *const AllocationCallbacks, *mut DebugUtilsMessengerEXT) -> Result>destroy_debug_utils_messenger_ext: Option<unsafe extern "system" fn(Instance, DebugUtilsMessengerEXT, *const AllocationCallbacks)>submit_debug_utils_message_ext: Option<unsafe extern "system" fn(Instance, DebugUtilsMessageSeverityFlagBitsEXT, DebugUtilsMessageTypeFlagBitsEXT, *const DebugUtilsMessengerCallbackDataEXT)>get_physical_device_cooperative_matrix_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut CooperativeMatrixPropertiesNV) -> Result>get_physical_device_surface_present_modes2_ext: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceSurfaceInfo2KHR, *mut u32, *mut PresentModeKHR) -> Result>enumerate_physical_device_queue_family_performance_query_counters_khr: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut u32, *mut PerformanceCounterKHR, *mut PerformanceCounterDescriptionKHR) -> Result>get_physical_device_queue_family_performance_query_passes_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const QueryPoolPerformanceCreateInfoKHR, *mut u32)>create_headless_surface_ext: Option<unsafe extern "system" fn(Instance, *const HeadlessSurfaceCreateInfoEXT, *const AllocationCallbacks, *mut SurfaceKHR) -> Result>get_physical_device_supported_framebuffer_mixed_samples_combinations_nv: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut FramebufferMixedSamplesCombinationNV) -> Result>get_physical_device_tool_properties: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut PhysicalDeviceToolProperties) -> Result>get_physical_device_refreshable_object_types_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut ObjectType) -> Result>get_physical_device_fragment_shading_rates_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut PhysicalDeviceFragmentShadingRateKHR) -> Result>get_physical_device_video_capabilities_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const VideoProfileInfoKHR, *mut VideoCapabilitiesKHR) -> Result>get_physical_device_video_format_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceVideoFormatInfoKHR, *mut u32, *mut VideoFormatPropertiesKHR) -> Result>get_physical_device_video_encode_quality_level_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceVideoEncodeQualityLevelInfoKHR, *mut VideoEncodeQualityLevelPropertiesKHR) -> Result>acquire_drm_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, i32, DisplayKHR) -> Result>get_drm_display_ext: Option<unsafe extern "system" fn(PhysicalDevice, i32, u32, *mut DisplayKHR) -> Result>get_physical_device_optical_flow_image_formats_nv: Option<unsafe extern "system" fn(PhysicalDevice, *const OpticalFlowImageFormatInfoNV, *mut u32, *mut OpticalFlowImageFormatPropertiesNV) -> Result>get_physical_device_cooperative_matrix_properties_khr: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut CooperativeMatrixPropertiesKHR) -> Result>get_physical_device_cooperative_matrix_flexible_dimensions_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut CooperativeMatrixFlexibleDimensionsPropertiesNV) -> Result>get_physical_device_cooperative_vector_properties_nv: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut CooperativeVectorPropertiesNV) -> Result>enumerate_physical_device_shader_instrumentation_metrics_arm: Option<unsafe extern "system" fn(PhysicalDevice, *mut u32, *mut ShaderInstrumentationMetricDescriptionARM) -> Result>get_physical_device_external_tensor_properties_arm: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceExternalTensorInfoARM, *mut ExternalTensorPropertiesARM)>get_physical_device_queue_family_data_graph_properties_arm: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut u32, *mut QueueFamilyDataGraphPropertiesARM) -> Result>get_physical_device_queue_family_data_graph_processing_engine_properties_arm: Option<unsafe extern "system" fn(PhysicalDevice, *const PhysicalDeviceQueueFamilyDataGraphProcessingEngineInfoARM, *mut QueueFamilyDataGraphProcessingEnginePropertiesARM)>enumerate_physical_device_queue_family_performance_counters_by_region_arm: Option<unsafe extern "system" fn(PhysicalDevice, u32, *mut u32, *mut PerformanceCounterARM, *mut PerformanceCounterDescriptionARM) -> Result>get_physical_device_descriptor_size_ext: Option<unsafe extern "system" fn(PhysicalDevice, DescriptorType) -> u64>Implementations
Sourceimpl InstanceCommands
impl InstanceCommands
Sourcepub unsafe fn load(f: impl FnMut(&CStr) -> *const c_void) -> InstanceCommands
pub unsafe fn load(f: impl FnMut(&CStr) -> *const c_void) -> InstanceCommands
Load all function pointers from the given loader callback.
Load all function pointers from the given loader callback.
Safety
The loader must return valid function pointers compatible with each command’s signature, or null for unavailable commands.