pub struct ImageLayout(/* private fields */);Expand description
Implementations
Sourceimpl ImageLayout
impl ImageLayout
Sourcepub const UNDEFINED: ImageLayout
pub const UNDEFINED: ImageLayout
Implicit layout an image is when its contents are undefined due to various reasons (e.g. right after creation)
Sourcepub const GENERAL: ImageLayout
pub const GENERAL: ImageLayout
General layout when image can be used for any kind of access
Sourcepub const COLOR_ATTACHMENT_OPTIMAL: ImageLayout
pub const COLOR_ATTACHMENT_OPTIMAL: ImageLayout
Optimal layout when image is only used for color attachment read/write
Sourcepub const DEPTH_STENCIL_ATTACHMENT_OPTIMAL: ImageLayout
pub const DEPTH_STENCIL_ATTACHMENT_OPTIMAL: ImageLayout
Optimal layout when image is only used for depth/stencil attachment read/write
Sourcepub const DEPTH_STENCIL_READ_ONLY_OPTIMAL: ImageLayout
pub const DEPTH_STENCIL_READ_ONLY_OPTIMAL: ImageLayout
Optimal layout when image is used for read only depth/stencil attachment and shader access
Sourcepub const SHADER_READ_ONLY_OPTIMAL: ImageLayout
pub const SHADER_READ_ONLY_OPTIMAL: ImageLayout
Optimal layout when image is used for read only shader access
Sourcepub const TRANSFER_SRC_OPTIMAL: ImageLayout
pub const TRANSFER_SRC_OPTIMAL: ImageLayout
Optimal layout when image is used only as source of transfer operations
Sourcepub const TRANSFER_DST_OPTIMAL: ImageLayout
pub const TRANSFER_DST_OPTIMAL: ImageLayout
Optimal layout when image is used only as destination of transfer operations
Sourcepub const PREINITIALIZED: ImageLayout
pub const PREINITIALIZED: ImageLayout
Initial layout used when the data is populated by the CPU
pub const DEPTH_READ_ONLY_STENCIL_ATTACHMENT_OPTIMAL: ImageLayout
pub const DEPTH_ATTACHMENT_STENCIL_READ_ONLY_OPTIMAL: ImageLayout
pub const DEPTH_ATTACHMENT_OPTIMAL: ImageLayout
pub const DEPTH_READ_ONLY_OPTIMAL: ImageLayout
pub const STENCIL_ATTACHMENT_OPTIMAL: ImageLayout
pub const STENCIL_READ_ONLY_OPTIMAL: ImageLayout
pub const READ_ONLY_OPTIMAL: ImageLayout
pub const ATTACHMENT_OPTIMAL: ImageLayout
pub const RENDERING_LOCAL_READ: ImageLayout
pub const PRESENT_SRC: ImageLayout
pub const VIDEO_DECODE_DST: ImageLayout
pub const VIDEO_DECODE_SRC: ImageLayout
pub const VIDEO_DECODE_DPB: ImageLayout
pub const SHARED_PRESENT: ImageLayout
pub const SHADING_RATE_OPTIMAL: ImageLayout = Self::FRAGMENT_SHADING_RATE_ATTACHMENT_OPTIMAL
pub const FRAGMENT_DENSITY_MAP_OPTIMAL: ImageLayout
pub const FRAGMENT_SHADING_RATE_ATTACHMENT_OPTIMAL: ImageLayout
pub const VIDEO_ENCODE_DST: ImageLayout
pub const VIDEO_ENCODE_SRC: ImageLayout
pub const VIDEO_ENCODE_DPB: ImageLayout
pub const ATTACHMENT_FEEDBACK_LOOP_OPTIMAL: ImageLayout
pub const TENSOR_ALIASING: ImageLayout
pub const VIDEO_ENCODE_QUANTIZATION_MAP: ImageLayout
pub const ZERO_INITIALIZED: ImageLayout
pub const fn from_raw(value: i32) -> ImageLayout
pub const fn as_raw(self) -> i32