#[repr(transparent)]pub struct StringArray<const N: usize>(pub [i8; N]);Expand description
A fixed-size array containing a null-terminated C string.
Wraps the raw [c_char; N] arrays used by Vulkan structs
(e.g. ExtensionProperties::extension_name). Equality and hashing
ignore bytes after the first null terminator.
Examples
use vulkan_rust_sys::StringArray;
let a = StringArray::<256>::from_cstr(c"VK_KHR_swapchain");
let b = StringArray::<256>::from_cstr(c"VK_KHR_swapchain");
assert_eq!(a, b);Tuple Fields
0: [i8; N]Implementations
Sourceimpl<const N: usize> StringArray<N>
impl<const N: usize> StringArray<N>
Sourcepub fn as_cstr(&self) -> &CStr
pub fn as_cstr(&self) -> &CStr
View the contents as a &CStr.
If the array contains no null terminator (shouldn’t happen with well-formed Vulkan data), treats the entire array as the string.
Sourcepub fn from_cstr(cstr: &CStr) -> StringArray<N>
pub fn from_cstr(cstr: &CStr) -> StringArray<N>
Construct from a &CStr, truncating if longer than N - 1.
Methods from Deref<Target = [i8; N]>
1.57.0 · Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice containing the entire array. Equivalent to &s[..].
1.77.0 · Sourcepub fn each_ref(&self) -> [&T; N]
pub fn each_ref(&self) -> [&T; N]
Borrows each element and returns an array of references with the same
size as self.
Example
let floats = [3.1, 2.7, -1.0];
let float_refs: [&f64; 3] = floats.each_ref();
assert_eq!(float_refs, [&3.1, &2.7, &-1.0]);This method is particularly useful if combined with other methods, like
map. This way, you can avoid moving the original
array if its elements are not Copy.
let strings = ["Ferris".to_string(), "♥".to_string(), "Rust".to_string()];
let is_ascii = strings.each_ref().map(|s| s.is_ascii());
assert_eq!(is_ascii, [true, false, true]);
// We can still access the original array: it has not been moved.
assert_eq!(strings.len(), 3);Sourcepub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
🔬This is a nightly-only experimental API. (split_array)
pub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
split_array)Divides one array reference into two at an index.
The first will contain all indices from [0, M) (excluding
the index M itself) and the second will contain all
indices from [M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.split_array_ref::<0>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<2>();
assert_eq!(left, &[1, 2]);
assert_eq!(right, &[3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<6>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}Sourcepub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
🔬This is a nightly-only experimental API. (split_array)
pub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
split_array)Divides one array reference into two at an index from the end.
The first will contain all indices from [0, N - M) (excluding
the index N - M itself) and the second will contain all
indices from [N - M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.rsplit_array_ref::<0>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}
{
let (left, right) = v.rsplit_array_ref::<2>();
assert_eq!(left, &[1, 2, 3, 4]);
assert_eq!(right, &[5, 6]);
}
{
let (left, right) = v.rsplit_array_ref::<6>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}Trait Implementations
Sourceimpl<const N: usize> Clone for StringArray<N>
impl<const N: usize> Clone for StringArray<N>
Sourcefn clone(&self) -> StringArray<N>
fn clone(&self) -> StringArray<N>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more