pub unsafe trait ExtendsAndroidSurfaceCreateInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
AndroidSurfaceCreateInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsAndroidSurfaceCreateInfoKHR { }Marker trait for structs that can appear in the pNext chain of
AndroidSurfaceCreateInfoKHR.
Implementors must be valid pNext chain members for the target struct.