pub unsafe trait ExtendsApplicationInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
ApplicationInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsApplicationInfo { }Marker trait for structs that can appear in the pNext chain of
ApplicationInfo.
Implementors must be valid pNext chain members for the target struct.