pub unsafe trait ExtendsAttachmentSampleCountInfoAMD { }Expand description
Marker trait for structs that can appear in the pNext chain of
AttachmentSampleCountInfoAMD.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsAttachmentSampleCountInfoAMD { }Marker trait for structs that can appear in the pNext chain of
AttachmentSampleCountInfoAMD.
Implementors must be valid pNext chain members for the target struct.