pub unsafe trait ExtendsBaseInStructure { }Expand description
Marker trait for structs that can appear in the pNext chain of
BaseInStructure.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBaseInStructure { }Marker trait for structs that can appear in the pNext chain of
BaseInStructure.
Implementors must be valid pNext chain members for the target struct.