pub unsafe trait ExtendsBaseOutStructure { }Expand description
Marker trait for structs that can appear in the pNext chain of
BaseOutStructure.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBaseOutStructure { }Marker trait for structs that can appear in the pNext chain of
BaseOutStructure.
Implementors must be valid pNext chain members for the target struct.