pub unsafe trait ExtendsBufferCopy2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
BufferCopy2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBufferCopy2 { }Marker trait for structs that can appear in the pNext chain of
BufferCopy2.
Implementors must be valid pNext chain members for the target struct.