pub unsafe trait ExtendsBufferCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
BufferCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBufferCreateInfo { }Marker trait for structs that can appear in the pNext chain of
BufferCreateInfo.
Implementors must be valid pNext chain members for the target struct.