pub unsafe trait ExtendsBufferMemoryBarrier { }Expand description
Marker trait for structs that can appear in the pNext chain of
BufferMemoryBarrier.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBufferMemoryBarrier { }Marker trait for structs that can appear in the pNext chain of
BufferMemoryBarrier.
Implementors must be valid pNext chain members for the target struct.