pub unsafe trait ExtendsCommandBufferBeginInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
CommandBufferBeginInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCommandBufferBeginInfo { }Marker trait for structs that can appear in the pNext chain of
CommandBufferBeginInfo.
Implementors must be valid pNext chain members for the target struct.