pub unsafe trait ExtendsCommandBufferSubmitInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
CommandBufferSubmitInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCommandBufferSubmitInfo { }Marker trait for structs that can appear in the pNext chain of
CommandBufferSubmitInfo.
Implementors must be valid pNext chain members for the target struct.