pub unsafe trait ExtendsComputePipelineCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
ComputePipelineCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsComputePipelineCreateInfo { }Marker trait for structs that can appear in the pNext chain of
ComputePipelineCreateInfo.
Implementors must be valid pNext chain members for the target struct.