pub unsafe trait ExtendsCopyDescriptorSet { }Expand description
Marker trait for structs that can appear in the pNext chain of
CopyDescriptorSet.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCopyDescriptorSet { }Marker trait for structs that can appear in the pNext chain of
CopyDescriptorSet.
Implementors must be valid pNext chain members for the target struct.