pub unsafe trait ExtendsCopyImageToMemoryInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
CopyImageToMemoryInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCopyImageToMemoryInfo { }Marker trait for structs that can appear in the pNext chain of
CopyImageToMemoryInfo.
Implementors must be valid pNext chain members for the target struct.