pub unsafe trait ExtendsCuFunctionCreateInfoNVX { }Expand description
Marker trait for structs that can appear in the pNext chain of
CuFunctionCreateInfoNVX.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCuFunctionCreateInfoNVX { }Marker trait for structs that can appear in the pNext chain of
CuFunctionCreateInfoNVX.
Implementors must be valid pNext chain members for the target struct.