pub unsafe trait ExtendsCuModuleCreateInfoNVX { }Expand description
Marker trait for structs that can appear in the pNext chain of
CuModuleCreateInfoNVX.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCuModuleCreateInfoNVX { }Marker trait for structs that can appear in the pNext chain of
CuModuleCreateInfoNVX.
Implementors must be valid pNext chain members for the target struct.