pub unsafe trait ExtendsCudaFunctionCreateInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
CudaFunctionCreateInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCudaFunctionCreateInfoNV { }Marker trait for structs that can appear in the pNext chain of
CudaFunctionCreateInfoNV.
Implementors must be valid pNext chain members for the target struct.