pub unsafe trait ExtendsCudaModuleCreateInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
CudaModuleCreateInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCudaModuleCreateInfoNV { }Marker trait for structs that can appear in the pNext chain of
CudaModuleCreateInfoNV.
Implementors must be valid pNext chain members for the target struct.