pub unsafe trait ExtendsDataGraphPipelineConstantARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
DataGraphPipelineConstantARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDataGraphPipelineConstantARM { }Marker trait for structs that can appear in the pNext chain of
DataGraphPipelineConstantARM.
Implementors must be valid pNext chain members for the target struct.