pub unsafe trait ExtendsDebugUtilsLabelEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DebugUtilsLabelEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDebugUtilsLabelEXT { }Marker trait for structs that can appear in the pNext chain of
DebugUtilsLabelEXT.
Implementors must be valid pNext chain members for the target struct.