pub unsafe trait ExtendsDebugUtilsObjectTagInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DebugUtilsObjectTagInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDebugUtilsObjectTagInfoEXT { }Marker trait for structs that can appear in the pNext chain of
DebugUtilsObjectTagInfoEXT.
Implementors must be valid pNext chain members for the target struct.