pub unsafe trait ExtendsDescriptorPoolCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
DescriptorPoolCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDescriptorPoolCreateInfo { }Marker trait for structs that can appear in the pNext chain of
DescriptorPoolCreateInfo.
Implementors must be valid pNext chain members for the target struct.