pub unsafe trait ExtendsDeviceCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
DeviceCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDeviceCreateInfo { }Marker trait for structs that can appear in the pNext chain of
DeviceCreateInfo.
Implementors must be valid pNext chain members for the target struct.