pub unsafe trait ExtendsDeviceFaultDebugInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
DeviceFaultDebugInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDeviceFaultDebugInfoKHR { }Marker trait for structs that can appear in the pNext chain of
DeviceFaultDebugInfoKHR.
Implementors must be valid pNext chain members for the target struct.