pub unsafe trait ExtendsDeviceGroupDeviceCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
DeviceGroupDeviceCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDeviceGroupDeviceCreateInfo { }Marker trait for structs that can appear in the pNext chain of
DeviceGroupDeviceCreateInfo.
Implementors must be valid pNext chain members for the target struct.