pub unsafe trait ExtendsDeviceMemoryImageCopyKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
DeviceMemoryImageCopyKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDeviceMemoryImageCopyKHR { }Marker trait for structs that can appear in the pNext chain of
DeviceMemoryImageCopyKHR.
Implementors must be valid pNext chain members for the target struct.