pub unsafe trait ExtendsDeviceQueueCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
DeviceQueueCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDeviceQueueCreateInfo { }Marker trait for structs that can appear in the pNext chain of
DeviceQueueCreateInfo.
Implementors must be valid pNext chain members for the target struct.