pub unsafe trait ExtendsExportSemaphoreCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExportSemaphoreCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExportSemaphoreCreateInfo { }Marker trait for structs that can appear in the pNext chain of
ExportSemaphoreCreateInfo.
Implementors must be valid pNext chain members for the target struct.