pub unsafe trait ExtendsExternalFormatOHOS { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExternalFormatOHOS.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExternalFormatOHOS { }Marker trait for structs that can appear in the pNext chain of
ExternalFormatOHOS.
Implementors must be valid pNext chain members for the target struct.