pub unsafe trait ExtendsExternalTensorPropertiesARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExternalTensorPropertiesARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExternalTensorPropertiesARM { }Marker trait for structs that can appear in the pNext chain of
ExternalTensorPropertiesARM.
Implementors must be valid pNext chain members for the target struct.