pub unsafe trait ExtendsFenceCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
FenceCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsFenceCreateInfo { }Marker trait for structs that can appear in the pNext chain of
FenceCreateInfo.
Implementors must be valid pNext chain members for the target struct.