pub unsafe trait ExtendsFramebufferCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
FramebufferCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsFramebufferCreateInfo { }Marker trait for structs that can appear in the pNext chain of
FramebufferCreateInfo.
Implementors must be valid pNext chain members for the target struct.