pub unsafe trait ExtendsImageCompressionControlEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageCompressionControlEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageCompressionControlEXT { }Marker trait for structs that can appear in the pNext chain of
ImageCompressionControlEXT.
Implementors must be valid pNext chain members for the target struct.