pub unsafe trait ExtendsImageMemoryBarrier { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageMemoryBarrier.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageMemoryBarrier { }Marker trait for structs that can appear in the pNext chain of
ImageMemoryBarrier.
Implementors must be valid pNext chain members for the target struct.