pub unsafe trait ExtendsImageToMemoryCopy { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageToMemoryCopy.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageToMemoryCopy { }Marker trait for structs that can appear in the pNext chain of
ImageToMemoryCopy.
Implementors must be valid pNext chain members for the target struct.