pub unsafe trait ExtendsImageViewASTCDecodeModeEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageViewASTCDecodeModeEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageViewASTCDecodeModeEXT { }Marker trait for structs that can appear in the pNext chain of
ImageViewASTCDecodeModeEXT.
Implementors must be valid pNext chain members for the target struct.