pub unsafe trait ExtendsImageViewCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageViewCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageViewCreateInfo { }Marker trait for structs that can appear in the pNext chain of
ImageViewCreateInfo.
Implementors must be valid pNext chain members for the target struct.