pub unsafe trait ExtendsInstanceCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
InstanceCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsInstanceCreateInfo { }Marker trait for structs that can appear in the pNext chain of
InstanceCreateInfo.
Implementors must be valid pNext chain members for the target struct.