pub unsafe trait ExtendsMappedMemoryRange { }Expand description
Marker trait for structs that can appear in the pNext chain of
MappedMemoryRange.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMappedMemoryRange { }Marker trait for structs that can appear in the pNext chain of
MappedMemoryRange.
Implementors must be valid pNext chain members for the target struct.