pub unsafe trait ExtendsMemoryBarrier { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryBarrier.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryBarrier { }Marker trait for structs that can appear in the pNext chain of
MemoryBarrier.
Implementors must be valid pNext chain members for the target struct.