pub unsafe trait ExtendsMemoryMarkerInfoAMD { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryMarkerInfoAMD.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryMarkerInfoAMD { }Marker trait for structs that can appear in the pNext chain of
MemoryMarkerInfoAMD.
Implementors must be valid pNext chain members for the target struct.