pub unsafe trait ExtendsMemoryToImageCopy { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryToImageCopy.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryToImageCopy { }Marker trait for structs that can appear in the pNext chain of
MemoryToImageCopy.
Implementors must be valid pNext chain members for the target struct.