pub unsafe trait ExtendsNativeBufferANDROID { }Expand description
Marker trait for structs that can appear in the pNext chain of
NativeBufferANDROID.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsNativeBufferANDROID { }Marker trait for structs that can appear in the pNext chain of
NativeBufferANDROID.
Implementors must be valid pNext chain members for the target struct.