pub unsafe trait ExtendsPerTileBeginInfoQCOM { }Expand description
Marker trait for structs that can appear in the pNext chain of
PerTileBeginInfoQCOM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPerTileBeginInfoQCOM { }Marker trait for structs that can appear in the pNext chain of
PerTileBeginInfoQCOM.
Implementors must be valid pNext chain members for the target struct.