pub unsafe trait ExtendsPipelineLayoutCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
PipelineLayoutCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPipelineLayoutCreateInfo { }Marker trait for structs that can appear in the pNext chain of
PipelineLayoutCreateInfo.
Implementors must be valid pNext chain members for the target struct.