pub unsafe trait ExtendsPipelineLibraryCreateInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
PipelineLibraryCreateInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPipelineLibraryCreateInfoKHR { }Marker trait for structs that can appear in the pNext chain of
PipelineLibraryCreateInfoKHR.
Implementors must be valid pNext chain members for the target struct.