pub unsafe trait ExtendsPresentFrameTokenGGP { }Expand description
Marker trait for structs that can appear in the pNext chain of
PresentFrameTokenGGP.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPresentFrameTokenGGP { }Marker trait for structs that can appear in the pNext chain of
PresentFrameTokenGGP.
Implementors must be valid pNext chain members for the target struct.