pub unsafe trait ExtendsProtectedSubmitInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
ProtectedSubmitInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsProtectedSubmitInfo { }Marker trait for structs that can appear in the pNext chain of
ProtectedSubmitInfo.
Implementors must be valid pNext chain members for the target struct.