pub unsafe trait ExtendsPushDescriptorSetInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
PushDescriptorSetInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPushDescriptorSetInfo { }Marker trait for structs that can appear in the pNext chain of
PushDescriptorSetInfo.
Implementors must be valid pNext chain members for the target struct.