pub unsafe trait ExtendsQueryPoolCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
QueryPoolCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsQueryPoolCreateInfo { }Marker trait for structs that can appear in the pNext chain of
QueryPoolCreateInfo.
Implementors must be valid pNext chain members for the target struct.