pub unsafe trait ExtendsRenderPassCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
RenderPassCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsRenderPassCreateInfo { }Marker trait for structs that can appear in the pNext chain of
RenderPassCreateInfo.
Implementors must be valid pNext chain members for the target struct.