pub unsafe trait ExtendsSamplerCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
SamplerCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSamplerCreateInfo { }Marker trait for structs that can appear in the pNext chain of
SamplerCreateInfo.
Implementors must be valid pNext chain members for the target struct.