pub unsafe trait ExtendsSemaphoreTypeCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
SemaphoreTypeCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSemaphoreTypeCreateInfo { }Marker trait for structs that can appear in the pNext chain of
SemaphoreTypeCreateInfo.
Implementors must be valid pNext chain members for the target struct.