pub unsafe trait ExtendsShaderModuleCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
ShaderModuleCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsShaderModuleCreateInfo { }Marker trait for structs that can appear in the pNext chain of
ShaderModuleCreateInfo.
Implementors must be valid pNext chain members for the target struct.