pub unsafe trait ExtendsSubmitInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
SubmitInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSubmitInfo { }Marker trait for structs that can appear in the pNext chain of
SubmitInfo.
Implementors must be valid pNext chain members for the target struct.