pub unsafe trait ExtendsSubpassDescription2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
SubpassDescription2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSubpassDescription2 { }Marker trait for structs that can appear in the pNext chain of
SubpassDescription2.
Implementors must be valid pNext chain members for the target struct.