pub unsafe trait ExtendsTensorDescriptionARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
TensorDescriptionARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTensorDescriptionARM { }Marker trait for structs that can appear in the pNext chain of
TensorDescriptionARM.
Implementors must be valid pNext chain members for the target struct.