pub unsafe trait ExtendsTensorMemoryBarrierARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
TensorMemoryBarrierARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTensorMemoryBarrierARM { }Marker trait for structs that can appear in the pNext chain of
TensorMemoryBarrierARM.
Implementors must be valid pNext chain members for the target struct.