pub unsafe trait ExtendsTileMemoryRequirementsQCOM { }Expand description
Marker trait for structs that can appear in the pNext chain of
TileMemoryRequirementsQCOM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTileMemoryRequirementsQCOM { }Marker trait for structs that can appear in the pNext chain of
TileMemoryRequirementsQCOM.
Implementors must be valid pNext chain members for the target struct.