pub unsafe trait ExtendsTileMemorySizeInfoQCOM { }Expand description
Marker trait for structs that can appear in the pNext chain of
TileMemorySizeInfoQCOM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTileMemorySizeInfoQCOM { }Marker trait for structs that can appear in the pNext chain of
TileMemorySizeInfoQCOM.
Implementors must be valid pNext chain members for the target struct.