pub unsafe trait ExtendsVideoBeginCodingInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoBeginCodingInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoBeginCodingInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoBeginCodingInfoKHR.
Implementors must be valid pNext chain members for the target struct.