pub unsafe trait ExtendsVideoCodingControlInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoCodingControlInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoCodingControlInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoCodingControlInfoKHR.
Implementors must be valid pNext chain members for the target struct.