pub unsafe trait ExtendsVideoEncodeInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoEncodeInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoEncodeInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoEncodeInfoKHR.
Implementors must be valid pNext chain members for the target struct.