pub unsafe trait ExtendsVideoEncodeUsageInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoEncodeUsageInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoEncodeUsageInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoEncodeUsageInfoKHR.
Implementors must be valid pNext chain members for the target struct.