pub unsafe trait ExtendsVideoFormatPropertiesKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoFormatPropertiesKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoFormatPropertiesKHR { }Marker trait for structs that can appear in the pNext chain of
VideoFormatPropertiesKHR.
Implementors must be valid pNext chain members for the target struct.