pub struct Result(/* private fields */);Expand description
Implementations
Sourceimpl Result
impl Result
Sourcepub const EVENT_RESET: Result
pub const EVENT_RESET: Result
An event is unsignaled
Sourcepub const INCOMPLETE: Result
pub const INCOMPLETE: Result
A return array was too small for the result
Sourcepub const ERROR_OUT_OF_HOST_MEMORY: Result
pub const ERROR_OUT_OF_HOST_MEMORY: Result
A host memory allocation has failed
Sourcepub const ERROR_OUT_OF_DEVICE_MEMORY: Result
pub const ERROR_OUT_OF_DEVICE_MEMORY: Result
A device memory allocation has failed
Sourcepub const ERROR_INITIALIZATION_FAILED: Result
pub const ERROR_INITIALIZATION_FAILED: Result
Initialization of an object has failed
Sourcepub const ERROR_DEVICE_LOST: Result
pub const ERROR_DEVICE_LOST: Result
The logical device has been lost. See devsandqueues-lost-device
Sourcepub const ERROR_MEMORY_MAP_FAILED: Result
pub const ERROR_MEMORY_MAP_FAILED: Result
Mapping of a memory object has failed
Sourcepub const ERROR_LAYER_NOT_PRESENT: Result
pub const ERROR_LAYER_NOT_PRESENT: Result
Layer specified does not exist
Sourcepub const ERROR_EXTENSION_NOT_PRESENT: Result
pub const ERROR_EXTENSION_NOT_PRESENT: Result
Extension specified does not exist
Sourcepub const ERROR_FEATURE_NOT_PRESENT: Result
pub const ERROR_FEATURE_NOT_PRESENT: Result
Requested feature is not available on this device
Sourcepub const ERROR_INCOMPATIBLE_DRIVER: Result
pub const ERROR_INCOMPATIBLE_DRIVER: Result
Unable to find a Vulkan driver
Sourcepub const ERROR_TOO_MANY_OBJECTS: Result
pub const ERROR_TOO_MANY_OBJECTS: Result
Too many objects of the type have already been created
Sourcepub const ERROR_FORMAT_NOT_SUPPORTED: Result
pub const ERROR_FORMAT_NOT_SUPPORTED: Result
Requested format is not supported on this device
Sourcepub const ERROR_FRAGMENTED_POOL: Result
pub const ERROR_FRAGMENTED_POOL: Result
A requested pool allocation has failed due to fragmentation of the pool’s memory
Sourcepub const ERROR_UNKNOWN: Result
pub const ERROR_UNKNOWN: Result
An unknown error has occurred, due to an implementation or application bug
pub const ERROR_VALIDATION_FAILED: Result
pub const ERROR_OUT_OF_POOL_MEMORY: Result
pub const ERROR_INVALID_EXTERNAL_HANDLE: Result
pub const ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS: Result
pub const ERROR_FRAGMENTATION: Result
pub const PIPELINE_COMPILE_REQUIRED: Result
pub const ERROR_NOT_PERMITTED: Result
pub const ERROR_INVALID_PIPELINE_CACHE_DATA: Result
pub const ERROR_NO_PIPELINE_MATCH: Result
pub const ERROR_SURFACE_LOST: Result
pub const ERROR_NATIVE_WINDOW_IN_USE: Result
pub const SUBOPTIMAL: Result
pub const ERROR_OUT_OF_DATE: Result
pub const ERROR_INCOMPATIBLE_DISPLAY: Result
pub const ERROR_INVALID_SHADER: Result
pub const ERROR_IMAGE_USAGE_NOT_SUPPORTED: Result
pub const ERROR_VIDEO_PICTURE_LAYOUT_NOT_SUPPORTED: Result
pub const ERROR_VIDEO_PROFILE_OPERATION_NOT_SUPPORTED: Result
pub const ERROR_VIDEO_PROFILE_FORMAT_NOT_SUPPORTED: Result
pub const ERROR_VIDEO_PROFILE_CODEC_NOT_SUPPORTED: Result
pub const ERROR_VIDEO_STD_VERSION_NOT_SUPPORTED: Result
pub const ERROR_INVALID_DRM_FORMAT_MODIFIER_PLANE_LAYOUT: Result
pub const ERROR_PRESENT_TIMING_QUEUE_FULL: Result
pub const ERROR_INVALID_DEVICE_ADDRESS: Result = Self::ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS
pub const ERROR_FULL_SCREEN_EXCLUSIVE_MODE_LOST: Result
pub const THREAD_IDLE: Result
pub const THREAD_DONE: Result
pub const OPERATION_DEFERRED: Result
pub const OPERATION_NOT_DEFERRED: Result
pub const ERROR_PIPELINE_COMPILE_REQUIRED: Result = Self::PIPELINE_COMPILE_REQUIRED
pub const ERROR_INVALID_VIDEO_STD_PARAMETERS: Result
pub const ERROR_COMPRESSION_EXHAUSTED: Result
pub const INCOMPATIBLE_SHADER_BINARY: Result
pub const ERROR_INCOMPATIBLE_SHADER_BINARY: Result = Self::INCOMPATIBLE_SHADER_BINARY
pub const PIPELINE_BINARY_MISSING: Result
pub const ERROR_NOT_ENOUGH_SPACE: Result
pub const fn from_raw(value: i32) -> Result
pub const fn as_raw(self) -> i32